==> jc-1.4.0.tar.gz: java/awt/datatransfer/Clipboard.h <==
// public class java.awt.datatransfer.Clipboard

// class file dependencies
// @dep_class 8c335465665e3ddb java_awt_datatransfer_Clipboard
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_datatransfer_Clipboard_H_
#define _JC_java_awt_datatransfer_Clipboard_H_

// Forward structure declarations
struct _jc_java_awt_datatransfer_ClipboardOwner$object;
struct _jc_java_awt_datatransfer_Transferable$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_datatransfer_Clipboard$sub_refs	_jc_java_awt_datatransfer_Clipboard$sub_refs;
typedef struct _jc_java_awt_datatransfer_Clipboard$sub_nonrefs	_jc_java_awt_datatransfer_Clipboard$sub_nonrefs;
typedef struct _jc_java_awt_datatransfer_Clipboard$refs	_jc_java_awt_datatransfer_Clipboard$refs;
typedef struct _jc_java_awt_datatransfer_Clipboard$nonrefs	_jc_java_awt_datatransfer_Clipboard$nonrefs;
typedef struct _jc_java_awt_datatransfer_Clipboard$object	_jc_java_awt_datatransfer_Clipboard$object;

typedef const struct _jc_java_awt_datatransfer_Clipboard$vmethods	_jc_java_awt_datatransfer_Clipboard$vmethods;
typedef const struct _jc_java_awt_datatransfer_Clipboard$vtable	_jc_java_awt_datatransfer_Clipboard$vtable;
typedef const struct _jc_java_awt_datatransfer_Clipboard$vtype	_jc_java_awt_datatransfer_Clipboard$vtype;

// Constructors
extern void _jc_java_awt_datatransfer_Clipboard$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_awt_datatransfer_Clipboard$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_object *_jc_java_awt_datatransfer_Clipboard$method$getContents$3780cd97213b3b38(_jc_env *, struct _jc_java_awt_datatransfer_Clipboard$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_String$object *_jc_java_awt_datatransfer_Clipboard$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_java_awt_datatransfer_Clipboard$object *);
extern void _jc_java_awt_datatransfer_Clipboard$method$setContents$90a1004e60b7abaa(_jc_env *, struct _jc_java_awt_datatransfer_Clipboard$object *, struct _jc_object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_datatransfer_Clipboard$method_info$getContents$3780cd97213b3b38;
extern _jc_method _jc_java_awt_datatransfer_Clipboard$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_java_awt_datatransfer_Clipboard$method_info$setContents$90a1004e60b7abaa;

// Virtual methods structure
struct _jc_java_awt_datatransfer_Clipboard$vmethods {
	struct _jc_object	*(*getContents$3780cd97213b3b38)(_jc_env *, struct _jc_java_awt_datatransfer_Clipboard$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_java_awt_datatransfer_Clipboard$object *);
	void	(*setContents$90a1004e60b7abaa)(_jc_env *, struct _jc_java_awt_datatransfer_Clipboard$object *, struct _jc_object *, struct _jc_object *);
};

// Vtable
struct _jc_java_awt_datatransfer_Clipboard$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_datatransfer_Clipboard$vmethods	java_awt_datatransfer_Clipboard;
};

// Vtype
struct _jc_java_awt_datatransfer_Clipboard$vtype {
	_jc_type			type;
	_jc_java_awt_datatransfer_Clipboard$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_datatransfer_Clipboard$sub_refs {
	struct _jc_object	*contents;
	struct _jc_object	*owner;
	struct _jc_java_lang_String$object	*name;
};

// Reference instance fields (object)
struct _jc_java_awt_datatransfer_Clipboard$refs {
    _jc_java_awt_datatransfer_Clipboard$sub_refs	java_awt_datatransfer_Clipboard;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_datatransfer_Clipboard$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_datatransfer_Clipboard$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_datatransfer_Clipboard$sub_nonrefs	java_awt_datatransfer_Clipboard;
};

// Object instance structure
struct _jc_java_awt_datatransfer_Clipboard$object {
	_jc_java_awt_datatransfer_Clipboard$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_datatransfer_Clipboard$vtype	*vtype;
	_jc_java_awt_datatransfer_Clipboard$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_datatransfer_Clipboard$vtype _jc_java_awt_datatransfer_Clipboard$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_datatransfer_Clipboard, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_datatransfer_Clipboard$class_object;

#endif	/* _JC_java_awt_datatransfer_Clipboard_H_ */

==> jc-1.4.6.tar.gz: java/awt/datatransfer/Clipboard.h <==
// public class java.awt.datatransfer.Clipboard

// class file dependencies
// @dep_class 8c335465665e3ddb java_awt_datatransfer_Clipboard
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_datatransfer_Clipboard_H_
#define _JC_java_awt_datatransfer_Clipboard_H_

// Forward structure declarations
struct _jc_java_awt_datatransfer_ClipboardOwner$object;
struct _jc_java_awt_datatransfer_Transferable$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_datatransfer_Clipboard$sub_refs	_jc_java_awt_datatransfer_Clipboard$sub_refs;
typedef struct _jc_java_awt_datatransfer_Clipboard$sub_nonrefs	_jc_java_awt_datatransfer_Clipboard$sub_nonrefs;
typedef struct _jc_java_awt_datatransfer_Clipboard$refs	_jc_java_awt_datatransfer_Clipboard$refs;
typedef struct _jc_java_awt_datatransfer_Clipboard$nonrefs	_jc_java_awt_datatransfer_Clipboard$nonrefs;
typedef struct _jc_java_awt_datatransfer_Clipboard$object	_jc_java_awt_datatransfer_Clipboard$object;

typedef const struct _jc_java_awt_datatransfer_Clipboard$vmethods	_jc_java_awt_datatransfer_Clipboard$vmethods;
typedef const struct _jc_java_awt_datatransfer_Clipboard$vtable	_jc_java_awt_datatransfer_Clipboard$vtable;
typedef const struct _jc_java_awt_datatransfer_Clipboard$vtype	_jc_java_awt_datatransfer_Clipboard$vtype;

// Constructors
extern void _jc_java_awt_datatransfer_Clipboard$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_awt_datatransfer_Clipboard$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_java_awt_datatransfer_Clipboard$method$getContents$3780cd97213b3b38(_jc_env *, struct _jc_java_awt_datatransfer_Clipboard$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_awt_datatransfer_Clipboard$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_java_awt_datatransfer_Clipboard$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_datatransfer_Clipboard$method$setContents$90a1004e60b7abaa(_jc_env *, struct _jc_java_awt_datatransfer_Clipboard$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_datatransfer_Clipboard$method_info$getContents$3780cd97213b3b38;
extern _jc_method _jc_java_awt_datatransfer_Clipboard$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_java_awt_datatransfer_Clipboard$method_info$setContents$90a1004e60b7abaa;

// Virtual methods structure
struct _jc_java_awt_datatransfer_Clipboard$vmethods {
	struct _jc_object	*(*getContents$3780cd97213b3b38)(_jc_env *, struct _jc_java_awt_datatransfer_Clipboard$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_java_awt_datatransfer_Clipboard$object *) _JC_JCNI_ATTR;
	void	(*setContents$90a1004e60b7abaa)(_jc_env *, struct _jc_java_awt_datatransfer_Clipboard$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_datatransfer_Clipboard$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_datatransfer_Clipboard$vmethods	java_awt_datatransfer_Clipboard;
};

// Vtype
struct _jc_java_awt_datatransfer_Clipboard$vtype {
	_jc_type			type;
	_jc_java_awt_datatransfer_Clipboard$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_datatransfer_Clipboard$sub_refs {
	struct _jc_object	*contents;
	struct _jc_object	*owner;
	struct _jc_java_lang_String$object	*name;
};

// Reference instance fields (object)
struct _jc_java_awt_datatransfer_Clipboard$refs {
    _jc_java_awt_datatransfer_Clipboard$sub_refs	java_awt_datatransfer_Clipboard;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_datatransfer_Clipboard$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_datatransfer_Clipboard$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_datatransfer_Clipboard$sub_nonrefs	java_awt_datatransfer_Clipboard;
};

// Object instance structure
struct _jc_java_awt_datatransfer_Clipboard$object {
	_jc_java_awt_datatransfer_Clipboard$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_datatransfer_Clipboard$vtype	*vtype;
	_jc_java_awt_datatransfer_Clipboard$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_datatransfer_Clipboard$vtype _jc_java_awt_datatransfer_Clipboard$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_datatransfer_Clipboard, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_datatransfer_Clipboard$class_object;

#endif	/* _JC_java_awt_datatransfer_Clipboard_H_ */
